@@ -47,6 +47,10 @@
 
 #include <lal/ConfigFile.h>
 
+// these constants are taken from StringConvert.c
+#define LAL_INT4_MAX    LAL_INT8_C(2147483647)
+#define LAL_INT8_MAX    LAL_INT8_C(9223372036854775807)
+
 #define FMT_STRING "string"    /* reading in quoted strings needs some special treatment */
 #define WHITESPACE " \t"
 
@@ -63,25 +67,38 @@ static void cleanConfig ( char *text );
  *
  * NOTE: This function can transparently detect and read gzip-compressed
  * data-files, independently of filename-extension
+ *
+ * NOTE2: allows passing of *file-contents* directly instead of filename to read
+ * by passing a string like "{ file-contents }" instead of a file-path,
+ * ie if first character == '{' and last character == '}'
+ * This is useful to allow ascii-file user inputs to be transparently
+ * passed as filenames or direct contents
  */
 int
 XLALParseDataFile (LALParsedDataFile **cfgdata, /**< [out] pre-parsed data-file lines */
-                   const CHAR *fname)		/**< [in] name of config-file to be read */
+                   const CHAR *path		/**< [in] file-path of config-file to be read */
+                   )
 {
   XLAL_CHECK ( (cfgdata != NULL) && (*cfgdata == NULL), XLAL_EINVAL );
-  XLAL_CHECK ( fname != NULL, XLAL_EINVAL );
+  XLAL_CHECK ( path != NULL, XLAL_EINVAL );
 
-  FILE *fp;
-  XLAL_CHECK ( (fp = LALOpenDataFile (fname)) != NULL, XLAL_EIO );
+  char *dataBuffer;
+  if ( (path[0] == '{') && (path[strlen(path)-1] == '}') )
+    {
+      XLAL_CHECK ( (dataBuffer = XLALStringDuplicate ( path + 1 )) != NULL, XLAL_EFUNC );
+      dataBuffer[strlen(dataBuffer)-1] = 0;
+    }
+  else
+    {
+      XLAL_CHECK ( (dataBuffer = XLALFileLoad ( path )) != NULL, XLAL_EFUNC );
+    }
 
-  CHARSequence *rawdata = NULL;
-  int err = XLALCHARReadSequence (&rawdata, fp);	// this function can read gzip-compressed files
-  fclose (fp);
-  XLAL_CHECK ( err == 0, XLAL_EFAILED, "XLALCHARReadSequence() failed with err = %d\n", err );
+  if ( XLALParseDataFileContent ( cfgdata, dataBuffer ) != XLAL_SUCCESS ) {
+    XLALFree ( dataBuffer );
+    XLAL_ERROR ( XLAL_EFUNC );
+  }
 
-  XLAL_CHECK ( XLALParseDataFileContent ( cfgdata, rawdata->data ) == XLAL_SUCCESS, XLAL_EFUNC );
-
-  XLALDestroyCHARVector ( rawdata );
+  XLALFree ( dataBuffer );
 
   return XLAL_SUCCESS;
 
@@ -266,16 +283,18 @@ XLALListConfigFileSections ( const LALParsedDataFile *cfgdata )    /**< [in] pre
  *
  * - <tt>param->varName</tt> is the name of the config-variable to read
  * - <tt>param->fmt</tt>     is the format string to use for reading
+ * - <tt>param->secName</tt> is the section name within which to find varName. NULL means 'default' section.
+ * - <tt>param->strictness</tt>   what to do if variable not found: ignore, warn, error
  *
- * \note a special format-string is FMT_STRING, which means read the whole remaining line
- * which is different from \"\%s\"! (reads only one word)
+ * \note a special format-string is FMT_STRING, which means read the whole remaining line (without initial whitespace!)
+ * which is different from \"\%s\"! (which would read only one word)
  * In this case, this also does the memory-allocation!
  *
  */
 int
 XLALReadConfigVariable ( void *varp,                      /**< [out] result gets written here! */
                          const LALParsedDataFile *cfgdata, /**< [in] pre-parsed config-data */
-                         const LALConfigVar *param,       /**< [in]  var-name, fmt-string, strictness */
+                         const LALConfigVar *param,       /**< [in]  var-name, section-name, fmt-string, strictness */
                          BOOLEAN *wasRead)                /**< [out] did we succeed in reading? */
 {
   CHAR *found    = NULL;
@@ -289,7 +308,7 @@ XLALReadConfigVariable ( void *varp,                      /**< [out] result gets
   size_t searchlen = strlen (param->varName);
   size_t sec_searchlen = 0;
 
-  if (param->secName == 0)
+  if (param->secName == NULL)
     {
       /* If we haven't been asked for a section then we want the
          "default" section, which starts at the top of the file */
@@ -455,47 +474,20 @@ XLALReadConfigBOOLVariable (BOOLEAN *varp,                 /**< [out] variable t
                             const CHAR *varName,                       /**< [in] variable-name to read */
                             BOOLEAN *wasRead)                          /**< [out] did we succeed in reading? */
 {
-  CHAR *tmp = NULL;
-  INT2 ret = -1;		/* -1 means no legal value has been parsed */
-  INT2 ret2;
-  *wasRead = FALSE;
-
+  (*wasRead) = FALSE;
   /* first read the value as a string */
-  if ( XLALReadConfigSTRINGVariable (&tmp, cfgdata, secName, varName, wasRead) != XLAL_SUCCESS ) {
-    XLALPrintError ("%s: XLALReadConfigSTRINGVariable() failed.\n", __func__);
-    XLAL_ERROR ( XLAL_EFUNC );
+  CHAR *valString = NULL;
+  /* first read the value as a string */
+  XLAL_CHECK ( XLALReadConfigSTRINGVariable (&valString, cfgdata, secName, varName, wasRead) == XLAL_SUCCESS, XLAL_EFUNC );
+
+  if ( ! (*wasRead ) ) { // if nothing was read and XLALReadConfigSTRINGVariable() didn't throw an error, then we're ok and return
+    return XLAL_SUCCESS;
   }
+  XLAL_CHECK ( valString != NULL, XLAL_EFAILED, "Got NULL string after reading config-variable '%s' in section '%s'\n", varName, secName ? secName: "default" );
 
-  if (*wasRead && tmp)		/* if we read anything at all... */
-    {
-      /* get rid of case ambiguities */
-      ret2 = XLALStringToLowerCase (tmp);
-
-      if (ret2)
-        return ret2;
-
-      /* try to parse it as a bool */
-      if (!strcmp (tmp, "yes") || !strcmp (tmp, "true") || !strcmp (tmp, "1"))
-        ret = 1;
-      else if (!strcmp (tmp, "no") || !strcmp (tmp, "false") || !strcmp (tmp, "0"))
-        ret = 0;
-      else
-        {
-          XLALPrintError ("%s: illegal bool-value `%s`\n", __func__, tmp);
-          XLALPrintError (CONFIGFILEH_MSGEBOOL);
-          XLALFree (tmp);
-          XLAL_ERROR ( XLAL_EINVAL );
-        }
-
-      XLALFree (tmp);
-
-      if (ret != -1)		/* only set value of something has been found */
-        {
-          *varp = (BOOLEAN) ret;
-          *wasRead = TRUE;
-        }
-    } /* if wasRead && tmp */
+  XLAL_CHECK ( XLALParseStringValueToBOOLEAN ( varp, valString ) == XLAL_SUCCESS, XLAL_EFUNC );
 
+  XLALFree (valString);
 
   return XLAL_SUCCESS;
 
@@ -503,7 +495,12 @@ XLALReadConfigBOOLVariable (BOOLEAN *varp,                 /**< [out] variable t
 
 
 /**
- * Type-specialization of generic reading-function LALReadConfigVariable() to INT4 variables.
+ * Read a signed integer value.
+ *
+ * Note: Rather than using the sscanf()-based LALReadConfigVariable() for the string-to-integer conversion,
+ * we do our own parsing, in order to check for spurious extra characters at the end.
+ * This allows us to catch user-input mistakes like specifying "1e3" for an int-variable, which
+ * would silently be converted as '1' by sscanf("%ld").
  */
 int
 XLALReadConfigINT4Variable (INT4 *varp,
@@ -512,14 +509,21 @@ XLALReadConfigINT4Variable (INT4 *varp,
                             const CHAR *varName,
                             BOOLEAN *wasRead)
 {
-  LALConfigVar param = { 0, 0, 0, CONFIGFILE_IGNORE };
+  (*wasRead) = FALSE;
+  /* first read the value as a string */
+  CHAR *valString = NULL;
+  XLAL_CHECK ( XLALReadConfigSTRINGVariable ( &valString, cfgdata, secName, varName, wasRead) == XLAL_SUCCESS, XLAL_EFUNC );
 
-  param.varName    = varName;
-  param.fmt        = "%" LAL_INT4_FORMAT;
-  param.strictness = CONFIGFILE_IGNORE;
-  param.secName    = secName;
+  if ( ! (*wasRead ) ) { // if nothing was read and XLALReadConfigSTRINGVariable() didn't throw an error, then we're ok and return
+    return XLAL_SUCCESS;
+  }
+  XLAL_CHECK ( valString != NULL, XLAL_EFAILED, "Got NULL string after reading config-variable '%s' in section '%s'\n", varName, secName ? secName: "default" );
 
-  return XLALReadConfigVariable ((void *) varp, cfgdata, &param, wasRead);
+  XLAL_CHECK ( XLALParseStringValueToINT4 ( varp, valString ) == XLAL_SUCCESS, XLAL_EFUNC );
+
+  XLALFree ( valString );
+
+  return XLAL_SUCCESS;
 
 } /* XLALReadConfigINT4Variable() */
 
@@ -534,14 +538,21 @@ XLALReadConfigREAL8Variable (REAL8 *varp,
                             const CHAR *varName,
                             BOOLEAN *wasRead)
 {
-  LALConfigVar param = {0,0,0, CONFIGFILE_IGNORE };
+  (*wasRead) = FALSE;
+  /* first read the value as a string */
+  CHAR *valString = NULL;
+  XLAL_CHECK ( XLALReadConfigSTRINGVariable ( &valString, cfgdata, secName, varName, wasRead) == XLAL_SUCCESS, XLAL_EFUNC );
 
-  param.secName = secName;
-  param.varName = varName;
-  param.fmt = "%" LAL_REAL8_FORMAT;
-  param.strictness = CONFIGFILE_IGNORE;
+  if ( ! (*wasRead ) ) { // if nothing was read and XLALReadConfigSTRINGVariable() didn't throw an error, then we're ok and return
+    return XLAL_SUCCESS;
+  }
+  XLAL_CHECK ( valString != NULL, XLAL_EFAILED, "Got NULL string after reading config-variable '%s' in section '%s'\n", varName, secName ? secName: "default" );
 
-  return XLALReadConfigVariable( (void*) varp, cfgdata, &param, wasRead);
+  XLAL_CHECK ( XLALParseStringValueToREAL8 ( varp, valString ) == XLAL_SUCCESS, XLAL_EFUNC );
+
+  XLALFree ( valString );
+
+  return XLAL_SUCCESS;
 
 } /* XLALReadConfigREAL8Variable() */
 
@@ -549,9 +560,8 @@ XLALReadConfigREAL8Variable (REAL8 *varp,
 /**
  * Type-specialization of generic reading-function XLALReadConfigVariable() to
  * STRING variables
- * \note this means the rest of the line, NOT "%s"! (but excluding comments of course),
- * \par Note2: if string is quoted by ", everything within quotes is read,
- * and the quotes are removed here
+ * \note this means the rest of the line (skipping initial whitespace and excluding trailing comments), NOT "%s"!
+ * \par Note2: if string is quoted by ", everything within quotes is read, and the quotes are removed here
  *
  */
 int
@@ -750,6 +760,143 @@ XLALCheckConfigReadComplete (const LALParsedDataFile *cfgdata,  /**< [in] config
 } /* XLALCheckConfigReadComplete() */
 
 
+//! Parse a string into an INT8
+//! This ignores initial whitespace, but throws an error on _any_ non-converted trailing characters (including whitespace)
+int
+XLALParseStringValueToINT8 ( INT8 *valINT8,         //!< [out] return INT8 value
+                             const char *valString  //!< [in]  input string value
+                             )
+{
+  XLAL_CHECK ( (valINT8 != NULL) && (valString != NULL ), XLAL_EINVAL );
+
+  errno = 0;
+  char *endptr;
+  int base10 = 10;
+  long long valLLong = strtoll ( valString, &endptr, base10 );
+  XLAL_CHECK ( errno == 0, XLAL_EFAILED, "strtoll() failed to convert '%s' into long long!\n", valString );
+  XLAL_CHECK ( (*endptr) == '\0', XLAL_EFAILED, "strtoll(): trailing garbage '%s' found after int-conversion of '%s'\n", endptr, valString );
+
+  //  check range and convert long-int into INT8
+  if ( sizeof(valLLong) > sizeof(INT8) ) { // avoid warning about trivial check
+    XLAL_CHECK ( (valLLong > -LAL_INT8_MAX) && (valLLong < LAL_INT8_MAX), XLAL_EDOM, "String-conversion '%s' --> '%ld' exceeds INT8 range of +-%d\n",
+                 valString, valLLong, LAL_INT8_MAX );
+  }
+
+  (*valINT8) = (INT8)valLLong;
+
+  return XLAL_SUCCESS;
+
+} // XLALParseStringValueToINT8()
+
+
+//! Parse a string into an INT4
+//! This ignores initial whitespace, but throws an error on _any_ non-converted trailing characters (including whitespace)
+int
+XLALParseStringValueToINT4 ( INT4 *valINT4,         //!< [out] return INT4 value
+                             const char *valString  //!< [in]  input string value
+                             )
+{
+  XLAL_CHECK ( (valINT4 != NULL) && (valString != NULL ), XLAL_EINVAL );
+
+  INT8 valINT8;
+  XLAL_CHECK ( XLALParseStringValueToINT8 ( &valINT8, valString ) == XLAL_SUCCESS, XLAL_EFUNC );
+
+  // check range and convert INT8 into INT4
+  XLAL_CHECK ( (valINT8 > -LAL_INT4_MAX) && (valINT8 < LAL_INT4_MAX), XLAL_EDOM, "String-conversion '%s' --> '%ld' exceeds INT4 range of +-%d\n",
+               valString, valINT8, LAL_INT4_MAX );
+
+  (*valINT4) = (INT4)valINT8;
+
+  return XLAL_SUCCESS;
+
+} // XLALParseStringValueToINT4()
+
+
+//! Parse a string into a REAL8
+//! This ignores initial whitespace, but throws an error on _any_ non-converted trailing characters (including whitespace)
+int
+XLALParseStringValueToREAL8 ( REAL8 *valREAL8,         //!< [out] return REAL8 value
+                              const char *valString    //!< [in]  input string value
+                              )
+{
+  XLAL_CHECK ( (valREAL8 != NULL) && (valString != NULL ), XLAL_EINVAL );
+
+  errno = 0;
+  char *endptr;
+  double valDouble = strtod ( valString, &endptr );
+  XLAL_CHECK ( errno == 0, XLAL_EFAILED, "strtod() failed to convert '%s' into a double!\n", valString );
+  XLAL_CHECK ( (*endptr) == '\0', XLAL_EFAILED, "strtod(): trailing garbage '%s' found after double-conversion of '%s'\n", endptr, valString );
+
+  (*valREAL8) = (REAL8)valDouble;
+
+  return XLAL_SUCCESS;
+
+} // XLALParseStringValueToREAL8()
+
+
+//! Parse a string into a REAL4.
+//! This ignores initial whitespace, but throws an error on _any_ non-converted trailing characters (including whitespace)
+int
+XLALParseStringValueToREAL4 ( REAL4 *valREAL4,         //!< [out] return REAL4 value
+                              const char *valString    //!< [in]  input string value
+                              )
+{
+  XLAL_CHECK ( (valREAL4 != NULL) && (valString != NULL ), XLAL_EINVAL );
+
+  errno = 0;
+  char *endptr;
+  float valFloat = strtof ( valString, &endptr );
+  XLAL_CHECK ( errno == 0, XLAL_EFAILED, "strtof() failed to convert '%s' into a float!\n", valString );
+  XLAL_CHECK ( (*endptr) == '\0', XLAL_EFAILED, "strtof(): trailing garbage '%s' found after float-conversion of '%s'\n", endptr, valString );
+
+  (*valREAL4) = (REAL4)valFloat;
+
+  return XLAL_SUCCESS;
+
+} // XLALParseStringValueToREAL8()
+
+
+//! Parse a string into a BOOLEAN
+//! Allowed string-values are (case-insensitive):
+//! {"yes", "true", "1"} --> TRUE
+//! {"no", "false", "0"} --> FALSE
+//!
+//! NOTE: This throws an error on _any_ extraneous leading or trailing characters or whitespace
+int
+XLALParseStringValueToBOOLEAN ( BOOLEAN *valBOOLEAN,     //!< [out] return BOOLEAN value
+                                const char *valString    //!< [in]  input string value
+                                )
+{
+  XLAL_CHECK ( (valBOOLEAN != NULL) && (valString != NULL ), XLAL_EINVAL );
+
+  /* get rid of case ambiguities */
+  char *valStringLower;
+  XLAL_CHECK ( (valStringLower = XLALMalloc ( strlen(valString) + 1 )) != NULL, XLAL_ENOMEM );
+  strcpy ( valStringLower, valString );
+  XLALStringToLowerCase ( valStringLower );
+
+  /* parse it as a bool */
+  if ( !strcmp(valStringLower, "yes") || !strcmp(valStringLower, "true") || !strcmp(valStringLower, "1") )
+    {
+      (*valBOOLEAN) = TRUE;
+    }
+  else if ( !strcmp(valStringLower, "no") || !strcmp(valStringLower, "false") || !strcmp(valStringLower, "0") )
+    {
+      (*valBOOLEAN) = FALSE;
+    }
+  else
+    {
+      XLALFree ( valStringLower );
+      XLAL_ERROR ( XLAL_EINVAL, "Illegal bool-string '%s', needs to be one of {'yes', 'true', '1'} or {'no', 'false', '0'} (case-insensitive)\n", valString );
+    }
+
+  XLALFree ( valStringLower );
+
+  return XLAL_SUCCESS;
+
+} // XLALParseStringValueToBOOLEAN()
+
+
 /*----------------------------------------------------------------------*/
 
 
