@@ -155,8 +155,7 @@ void XLALDestroyREAL4FFTPlan( REAL4FFTPlan *plan )
   return;
 }
 
-int XLALREAL4ForwardFFT( COMPLEX8Vector *output, const REAL4Vector *input,
-    const REAL4FFTPlan *plan )
+int XLALREAL4ForwardFFT( COMPLEX8Vector *output, const REAL4Vector *input, const REAL4FFTPlan *plan )
 {
   if ( ! output || ! input || ! plan )
     XLAL_ERROR( XLAL_EFAULT );
@@ -193,8 +192,7 @@ int XLALREAL4ForwardFFT( COMPLEX8Vector *output, const REAL4Vector *input,
 }
 
 
-int XLALREAL4ReverseFFT( REAL4Vector *output, const COMPLEX8Vector *input,
-    const REAL4FFTPlan *plan )
+int XLALREAL4ReverseFFT( REAL4Vector *output, const COMPLEX8Vector *input, const REAL4FFTPlan *plan )
 {
   if ( ! output || ! input || ! plan )
     XLAL_ERROR( XLAL_EFAULT );
@@ -229,8 +227,7 @@ int XLALREAL4ReverseFFT( REAL4Vector *output, const COMPLEX8Vector *input,
 }
 
 
-int XLALREAL4VectorFFT( REAL4Vector *output, const REAL4Vector *input,
-    const REAL4FFTPlan *plan )
+int XLALREAL4VectorFFT( REAL4Vector * _LAL_RESTRICT_ output, const REAL4Vector * _LAL_RESTRICT_ input, const REAL4FFTPlan *plan )
 {
   COMPLEX8 *tmp;
   UINT4 k;
@@ -468,8 +465,7 @@ void XLALDestroyREAL8FFTPlan( REAL8FFTPlan *plan )
   return;
 }
 
-int XLALREAL8ForwardFFT( COMPLEX16Vector *output, REAL8Vector *input,
-    const REAL8FFTPlan *plan )
+int XLALREAL8ForwardFFT( COMPLEX16Vector *output, const REAL8Vector *input, const REAL8FFTPlan *plan )
 {
   REAL8 *tmp;
   UINT4 k;
@@ -516,8 +512,7 @@ int XLALREAL8ForwardFFT( COMPLEX16Vector *output, REAL8Vector *input,
 }
 
 
-int XLALREAL8ReverseFFT( REAL8Vector *output, COMPLEX16Vector *input,
-    const REAL8FFTPlan *plan )
+int XLALREAL8ReverseFFT( REAL8Vector *output, const COMPLEX16Vector *input, const REAL8FFTPlan *plan )
 {
   REAL8 *tmp;
   UINT4 k;
@@ -568,8 +563,7 @@ int XLALREAL8ReverseFFT( REAL8Vector *output, COMPLEX16Vector *input,
 }
 
 
-int XLALREAL8VectorFFT( REAL8Vector *output, REAL8Vector *input,
-    const REAL8FFTPlan *plan )
+int XLALREAL8VectorFFT( REAL8Vector * _LAL_RESTRICT_ output, const REAL8Vector * _LAL_RESTRICT_ input, const REAL8FFTPlan *plan )
 {
   if ( ! output || ! input || ! plan )
     XLAL_ERROR( XLAL_EFAULT );
