@@ -586,7 +586,11 @@ const LALDetector lalCachedDetectors[LAL_NUM_DETECTORS] = {
   LAL_DETECTOR_STRUCT( AURIGA, CYLBAR ),
   LAL_DETECTOR_STRUCT( EXPLORER, CYLBAR ),
   LAL_DETECTOR_STRUCT( NIOBE, CYLBAR ),
-  LAL_DETECTOR_STRUCT( NAUTILUS, CYLBAR )
+  LAL_DETECTOR_STRUCT( NAUTILUS, CYLBAR ),
+  LAL_DETECTOR_STRUCT( ET1, IFODIFF ),
+  LAL_DETECTOR_STRUCT( ET2, IFODIFF ),
+  LAL_DETECTOR_STRUCT( ET3, IFODIFF ),
+  LAL_DETECTOR_STRUCT( ET0, IFODIFF )
 };
 
 
