@@ -1,5 +1,5 @@
 /*
-*  Copyright (C) 2010 Michele Vallisneri, Will Farr, Evan Ochsner
+*  Copyright (C) 2010 Michele Vallisneri, Will Farr, Evan Ochsner, 2014 A. Klein
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
@@ -536,3 +536,252 @@ int XLALAdaptiveRungeKutta4( ark4GSLIntegrator *integrator,
 	*yout = output;
   return outputlen; /* TO DO: check XLAL error reporting conventions */
 }
+
+
+
+
+
+/**
+ * Fourth-order Runge-Kutta ODE integrator using Runge-Kutta-Fehlberg (RKF45)
+ * steps with adaptive step size control.  Intended for use in Fourier domain
+ * waveform generation routines based on SpinTaylorTN models.
+ *
+ * The method is described in
+ *
+ * Abramowitz & Stegun, Handbook of Mathematical Functions, Tenth Printing,
+ * National Bureau of Standards, Washington, DC, 1972
+ * (available online at http://people.math.sfu.ca/~cbm/aands/ )
+ *
+ * This method is equivalent to XLALAdaptiveRungeKutta4 and
+ * XLALAdaptiveRungeKutta4Hermite, but does not includes any interpolation.
+ *
+ */
+int XLALAdaptiveRungeKutta4IrregularIntervals( ark4GSLIntegrator *integrator,      /**< struct holding dydt, stopping test, stepper, etc. */
+                                    void *params,                       /**< params struct used to compute dydt and stopping test */
+                                    REAL8 *yinit,                       /**< pass in initial values of all variables - overwritten to final values */
+                                    REAL8 tinit,                        /**< integration start time */
+                                    REAL8 tend_in,                      /**< maximum integration time */
+                                    REAL8Array **yout                   /**< array holding the unevenly sampled output */
+                                    )
+{
+  UINT4 MaxRK4Steps = 1000000;
+  int status; /* used throughout */
+  unsigned int i;
+
+  // if we integrate forward in time, we start at i=0, and if we integrate backwards, we start at i=MaxRK4Steps-1
+  unsigned int iStart, iCurrent;
+  int di;
+
+  REAL8 tend = tend_in;
+
+        /* needed for the integration */
+  size_t dim, bufferlength, cnt, retries;
+        REAL8 t, tnew, h0;
+  REAL8Array *buffers = NULL;
+  REAL8 *temp = NULL, *y, *y0, *dydt_in, *dydt_in0, *dydt_out, *yerr; /* aliases */
+
+  int outputlen = 0;
+  REAL8Array *output = NULL;
+
+  /* allocate the buffers!
+           note: REAL8Array has a field dimLength (UINT4Vector) with dimensions, and a field data that points to a single memory block;
+                 dimLength itself has fields length and data */
+  dim = integrator->sys->dimension;
+  bufferlength = MaxRK4Steps;
+  buffers = XLALCreateREAL8ArrayL(2, dim+2, bufferlength);        /* 2-dimensional array, (dim+2) x bufferlength */
+  temp = LALCalloc(6*dim,sizeof(REAL8));
+
+  if (!buffers || !temp) {
+    status = XLAL_ENOMEM;
+    goto bail_out;
+  }
+
+        y = temp; y0 = temp + dim; dydt_in = temp + 2*dim; dydt_in0 = temp + 3*dim; dydt_out = temp + 4*dim; yerr = temp + 5*dim; /* aliases */
+
+  /* set up to get started */
+  integrator->sys->params = params;
+
+        integrator->returncode = 0;
+
+  cnt = 0;
+  retries = integrator->retries;
+
+  t = tinit;
+  if(tend > tinit)
+  {
+    h0 = 1.;
+  }
+  else
+  {
+    h0 = -1.;
+  }
+  memcpy(y,yinit,dim*sizeof(REAL8));
+
+
+  // current index starts at iStart, and increases in steps of di. We've reached the memory limit if cnt == bufferlength.
+  if(h0 > 0.)
+  {
+    iStart = 0;
+    di = 1;
+  }
+  else
+  {
+    iStart = MaxRK4Steps-1;
+    di = -1;
+  }
+
+  iCurrent = iStart;
+
+
+  /* store the first data point */
+  buffers->data[iCurrent] = t;
+  for(i=1;i<=dim;i++) buffers->data[i*bufferlength+iCurrent] = y[i-1];
+
+  /* compute derivatives at the initial time (dydt_in), bail out if impossible */
+  if ((status = integrator->dydt(t,y,dydt_in,params)) != GSL_SUCCESS) {
+                integrator->returncode = status;
+                goto bail_out;
+        }
+
+  buffers->data[i*bufferlength + iCurrent] = dydt_in[1]; /* add domega/dt. here i=dim+1 */
+
+        /* note: for speed, this replaces the single CALLGSL wrapper applied before each GSL call */
+        XLAL_BEGINGSL;
+
+  while(1) {
+
+     if (!integrator->stopontestonly && t >= tend) {
+                        break;
+     }
+
+                if (integrator->stop) {
+      if ((status = integrator->stop(t,y,dydt_in,params)) != GSL_SUCCESS) {
+                                integrator->returncode = status;
+                                break;
+                        }
+                }
+
+                /* ready to try stepping! */
+    try_step:
+
+                /* if we would be stepping beyond the final time, stop there instead... */
+    if (!integrator->stopontestonly && t + h0 > tend) h0 = tend - t;
+
+    memcpy(y0      ,y,      dim*sizeof(REAL8));   /* save y to y0, dydt_in to dydt_in0 */
+                memcpy(dydt_in0,dydt_in,dim*sizeof(REAL8));
+
+    /* call the GSL stepper function */
+                status = gsl_odeiv_step_apply(integrator->step,t,h0,y,yerr,dydt_in,dydt_out,integrator->sys);
+                /* note: If the user-supplied functions defined in the system dydt return a status other than GSL_SUCCESS,
+                   the step will be aborted. In this case, the elements of y will be restored to their pre-step values,
+                   and the error code from the user-supplied function will be returned. */
+
+                /* did the stepper report a derivative-evaluation error? */
+    if (status != GSL_SUCCESS) {
+      if (retries--) {
+        h0 = h0 / 10.0;               /* if we have singularity retries left, reduce the timestep and try again */
+        goto try_step;
+      } else {
+                                integrator->returncode = status;
+                                break;                        /* otherwise exit the loop */
+      }
+    } else {
+      retries = integrator->retries;  /* we stepped successfully, reset the singularity retries */
+    }
+
+    tnew = t + h0;
+
+    /* call the GSL error-checking function */
+    status = gsl_odeiv_control_hadjust(integrator->control,integrator->step,y,yerr,dydt_out,&h0);
+
+                /* did the error-checker reduce the stepsize?
+                   note: other possible return codes are GSL_ODEIV_HADJ_INC if it was increased, GSL_ODEIV_HADJ_NIL if it was unchanged */
+    if (status == GSL_ODEIV_HADJ_DEC) {
+      memcpy(y,      y0,      dim*sizeof(REAL8));       /* if so, undo the step, and try again */
+                        memcpy(dydt_in,dydt_in0,dim*sizeof(REAL8));
+                        goto try_step;
+    }
+
+                /* update the current time and input derivatives */
+    t = tnew;
+    memcpy(dydt_in,dydt_out,dim*sizeof(REAL8));
+    cnt++;
+    iCurrent += di;
+
+    /* check if interpolation buffers need to be extended */
+    if (cnt >= bufferlength) {
+                        REAL8Array *rebuffers;
+
+                                /* sadly, we cannot use ResizeREAL8Array, because it would only work if we extended the first array dimension,
+                                         so we need to copy everything over and switch the buffers. Oh well. */
+      if (!(rebuffers = XLALCreateREAL8ArrayL(2,dim+1,2*bufferlength)))
+      {
+        status = XLAL_ENOMEM;   /* ouch, that hurt */
+        goto bail_out;
+      }
+      else
+      {
+        for(i=0; i<=dim; i++) memcpy(&rebuffers->data[i*2*bufferlength],&buffers->data[i*bufferlength],cnt*sizeof(REAL8));
+        XLALDestroyREAL8Array(buffers); buffers = rebuffers;
+        bufferlength *= 2;
+        if(di < 0)
+        {
+          iCurrent += bufferlength;
+        }
+      }
+    }
+
+    /* copy time and state into interpolation buffers */
+    buffers->data[iCurrent] = t;
+    for(i=1; i<=dim; i++) buffers->data[i*bufferlength + iCurrent] = y[i-1]; /* y does not have time */
+
+    buffers->data[i*bufferlength + iCurrent] = dydt_in[1]; /* add domega/dt. here i=dim+1 */
+  }
+
+        XLAL_ENDGSL;
+
+        /* copy the final state into yinit */
+
+        memcpy(yinit,y,dim*sizeof(REAL8));
+
+  /* if we have completed at least one step, allocate the output array */
+  if (cnt == 0) goto bail_out;
+
+
+  outputlen = cnt+1;
+  output = XLALCreateREAL8ArrayL(2,dim+2,outputlen);
+
+  // depending on the direction of integration, we copy starting from 0 or from the current index
+  if(di > 0)
+  {
+    iStart = 0;
+  }
+  else
+  {
+    iStart = iCurrent;
+  }
+
+
+  if (!output) {
+    status = XLAL_ENOMEM;       /* ouch again, ran out of memory */
+          if (output) XLALDestroyREAL8Array(output);
+                outputlen = 0;
+    goto bail_out;
+  }
+
+  for(i = 0; i <= dim+1; i++)
+  {
+    memcpy(&(output->data[i*outputlen]), &(buffers->data[i*bufferlength + iStart]), outputlen*sizeof(REAL8));
+  }
+
+  /* deallocate stuff and return */
+  bail_out:
+
+  if (buffers) XLALDestroyREAL8Array(buffers);   /* let's be careful, although all these checks may not be needed */
+  if (temp)    LALFree(temp);
+
+  if (status == XLAL_ENOMEM) XLAL_ERROR(XLAL_ENOMEM);   /* TO DO: will this return? */
+
+        *yout = output;
+  return outputlen; /* TO DO: check XLAL error reporting conventions */
+}
