@@ -233,10 +233,7 @@ main( int argc, char *argv[] )
    COMPLEX16FrequencySeries             goodInput;
    COMPLEX16FrequencySeries     goodOutput;
 
-   BOOLEAN                result;
-   LALUnitPair            unitPair;
-
-   CHARVector             *unitString;
+   int                    result;
 
    FrequencySamplingParams     params;
 
@@ -623,55 +620,22 @@ main( int argc, char *argv[] )
    }
 
    /* check output units */
-   unitPair.unitOne = &(goodInput.sampleUnits);
-   unitPair.unitTwo = &(goodOutput.sampleUnits);
-   LALUnitCompare(&status, &result, &unitPair);
-   if ( ( code = CheckStatus(&status, 0 , "",
-			     ZCOARSEGRAINFREQUENCYSERIESTESTC_EFLS,
-			     ZCOARSEGRAINFREQUENCYSERIESTESTC_MSGEFLS) ) )
-   {
-     return code;
-   }
+   result = XLALUnitCompare( &(goodInput.sampleUnits), &(goodOutput.sampleUnits) );
 
    if (optVerbose)
    {
-     unitString = NULL;
-     LALCHARCreateVector(&status, &unitString, LALUnitTextSize);
-     if ( ( code = CheckStatus(&status, 0 , "",
-			       ZCOARSEGRAINFREQUENCYSERIESTESTC_EFLS,
-			       ZCOARSEGRAINFREQUENCYSERIESTESTC_MSGEFLS) ) )
-     {
-       return code;
+     CHAR unitString[LALUnitTextSize];
+     if ( XLALUnitAsString( unitString, LALUnitTextSize, &(goodOutput.sampleUnits)) == NULL ) {
+       return ZCOARSEGRAINFREQUENCYSERIESTESTC_EFLS;
      }
-
-     LALUnitAsString( &status, unitString, unitPair.unitTwo );
-     if ( ( code = CheckStatus(&status, 0 , "",
-			       ZCOARSEGRAINFREQUENCYSERIESTESTC_EFLS,
-			       ZCOARSEGRAINFREQUENCYSERIESTESTC_MSGEFLS) ) )
-     {
-       return code;
-     }
-     printf( "Units are \"%s\", ", unitString->data );
-
-     LALUnitAsString( &status, unitString, unitPair.unitOne );
-     if ( ( code = CheckStatus(&status, 0 , "",
-			       ZCOARSEGRAINFREQUENCYSERIESTESTC_EFLS,
-			       ZCOARSEGRAINFREQUENCYSERIESTESTC_MSGEFLS) ) )
-     {
-       return code;
-     }
-     printf( "should be \"%s\"\n", unitString->data );
-
-     LALCHARDestroyVector(&status, &unitString);
-     if ( ( code = CheckStatus(&status, 0 , "",
-			       ZCOARSEGRAINFREQUENCYSERIESTESTC_EFLS,
-			       ZCOARSEGRAINFREQUENCYSERIESTESTC_MSGEFLS) ) )
-     {
-       return code;
+     printf( "Units are \"%s\", ", unitString );
+     if ( XLALUnitAsString( unitString, LALUnitTextSize, &(goodInput.sampleUnits)) == NULL ) {
+       return ZCOARSEGRAINFREQUENCYSERIESTESTC_EFLS;
      }
+     printf( "should be \"%s\"\n", unitString );
    }
 
-   if (!result)
+   if (result != 0)
    {
      printf("  FAIL: Valid data test #1\n");
      if (optVerbose)
@@ -820,55 +784,22 @@ main( int argc, char *argv[] )
    }
 
    /* check output units */
-   unitPair.unitOne = &(goodInput.sampleUnits);
-   unitPair.unitTwo = &(goodOutput.sampleUnits);
-   LALUnitCompare(&status, &result, &unitPair);
-   if ( ( code = CheckStatus(&status, 0 , "",
-			     ZCOARSEGRAINFREQUENCYSERIESTESTC_EFLS,
-			     ZCOARSEGRAINFREQUENCYSERIESTESTC_MSGEFLS) ) )
-   {
-     return code;
-   }
+   result = XLALUnitCompare( &(goodInput.sampleUnits), &(goodOutput.sampleUnits) );
 
    if (optVerbose)
    {
-     unitString = NULL;
-     LALCHARCreateVector(&status, &unitString, LALUnitTextSize);
-     if ( ( code = CheckStatus(&status, 0 , "",
-			       ZCOARSEGRAINFREQUENCYSERIESTESTC_EFLS,
-			       ZCOARSEGRAINFREQUENCYSERIESTESTC_MSGEFLS) ) )
-     {
-       return code;
+     CHAR unitString[LALUnitTextSize];
+     if ( XLALUnitAsString( unitString, LALUnitTextSize, &(goodOutput.sampleUnits)) == NULL ) {
+       return ZCOARSEGRAINFREQUENCYSERIESTESTC_EFLS;
      }
-
-     LALUnitAsString( &status, unitString, unitPair.unitTwo );
-     if ( ( code = CheckStatus(&status, 0 , "",
-			       ZCOARSEGRAINFREQUENCYSERIESTESTC_EFLS,
-			       ZCOARSEGRAINFREQUENCYSERIESTESTC_MSGEFLS) ) )
-     {
-       return code;
-     }
-     printf( "Units are \"%s\", ", unitString->data );
-
-     LALUnitAsString( &status, unitString, unitPair.unitOne );
-     if ( ( code = CheckStatus(&status, 0 , "",
-			       ZCOARSEGRAINFREQUENCYSERIESTESTC_EFLS,
-			       ZCOARSEGRAINFREQUENCYSERIESTESTC_MSGEFLS) ) )
-     {
-       return code;
-     }
-     printf( "should be \"%s\"\n", unitString->data );
-
-     LALCHARDestroyVector(&status, &unitString);
-     if ( ( code = CheckStatus(&status, 0 , "",
-			       ZCOARSEGRAINFREQUENCYSERIESTESTC_EFLS,
-			       ZCOARSEGRAINFREQUENCYSERIESTESTC_MSGEFLS) ) )
-     {
-       return code;
+     printf( "Units are \"%s\", ", unitString );
+     if ( XLALUnitAsString( unitString, LALUnitTextSize, &(goodInput.sampleUnits)) == NULL ) {
+       return ZCOARSEGRAINFREQUENCYSERIESTESTC_EFLS;
      }
+     printf( "should be \"%s\"\n", unitString );
    }
 
-   if (!result)
+   if (result != 0)
    {
      printf("  FAIL: Valid data test #2\n");
      if (optVerbose)
@@ -1046,55 +977,22 @@ main( int argc, char *argv[] )
    }
 
    /* check output units */
-   unitPair.unitOne = &(goodInput.sampleUnits);
-   unitPair.unitTwo = &(goodOutput.sampleUnits);
-   LALUnitCompare(&status, &result, &unitPair);
-   if ( ( code = CheckStatus(&status, 0 , "",
-			     ZCOARSEGRAINFREQUENCYSERIESTESTC_EFLS,
-			     ZCOARSEGRAINFREQUENCYSERIESTESTC_MSGEFLS) ) )
-   {
-     return code;
-   }
+   result = XLALUnitCompare( &(goodInput.sampleUnits), &(goodOutput.sampleUnits) );
 
    if (optVerbose)
    {
-     unitString = NULL;
-     LALCHARCreateVector(&status, &unitString, LALUnitTextSize);
-     if ( ( code = CheckStatus(&status, 0 , "",
-			       ZCOARSEGRAINFREQUENCYSERIESTESTC_EFLS,
-			       ZCOARSEGRAINFREQUENCYSERIESTESTC_MSGEFLS) ) )
-     {
-       return code;
+     CHAR unitString[LALUnitTextSize];
+     if ( XLALUnitAsString( unitString, LALUnitTextSize, &(goodOutput.sampleUnits)) == NULL ) {
+       return ZCOARSEGRAINFREQUENCYSERIESTESTC_EFLS;
      }
-
-     LALUnitAsString( &status, unitString, unitPair.unitTwo );
-     if ( ( code = CheckStatus(&status, 0 , "",
-			       ZCOARSEGRAINFREQUENCYSERIESTESTC_EFLS,
-			       ZCOARSEGRAINFREQUENCYSERIESTESTC_MSGEFLS) ) )
-     {
-       return code;
-     }
-     printf( "Units are \"%s\", ", unitString->data );
-
-     LALUnitAsString( &status, unitString, unitPair.unitOne );
-     if ( ( code = CheckStatus(&status, 0 , "",
-			       ZCOARSEGRAINFREQUENCYSERIESTESTC_EFLS,
-			       ZCOARSEGRAINFREQUENCYSERIESTESTC_MSGEFLS) ) )
-     {
-       return code;
-     }
-     printf( "should be \"%s\"\n", unitString->data );
-
-     LALCHARDestroyVector(&status, &unitString);
-     if ( ( code = CheckStatus(&status, 0 , "",
-			       ZCOARSEGRAINFREQUENCYSERIESTESTC_EFLS,
-			       ZCOARSEGRAINFREQUENCYSERIESTESTC_MSGEFLS) ) )
-     {
-       return code;
+     printf( "Units are \"%s\", ", unitString );
+     if ( XLALUnitAsString( unitString, LALUnitTextSize, &(goodInput.sampleUnits)) == NULL ) {
+       return ZCOARSEGRAINFREQUENCYSERIESTESTC_EFLS;
      }
+     printf( "should be \"%s\"\n", unitString );
    }
 
-   if (!result)
+   if (result != 0)
    {
      printf("  FAIL: Valid data test #3\n");
      if (optVerbose)
